<dl id="table-refresh-info" class="stats stats-horizontal shadow leading-none overflow-x-auto font-medium bg-neutral text-neutral-content">
    <div class="stat py-2">
        <dt class="stat-title text-neutral-content/80">Total, all time</dt>
        <dd class="stat-value text-2xl text-base"> {{ count }}</dd>
    </div>
    <div class="stat py-2">
        <dt class="stat-title text-neutral-content/80">After filtering</dt>
        <dd class="stat-value text-2xl text-base"> {{ filtered_count }}</dd>
    </div>
    <div class="stat py-2">
        <dt class="stat-title text-neutral-content/80">Per page</dt>
        <dd class="stat-value text-2xl text-base">{{ per_page }}</dd>
    </div>
    <div class="stat py-2">
        <dt class="stat-title text-neutral-content/80">Last refreshed</dt>
        <dd class="stat-value text-2xl text-base">{{ last_refreshed|date:datetime_format|default:"?" }}</dd>
    </div>
    <div class="stat py-2">
        <dt class="stat-title text-neutral-content/80">Updating every</dt>
        <dd class="stat-value text-2xl text-base">{{ update_interval|default:"?" }}s</dd>
    </div>
</dl>
